@@ -48,19 +48,12 @@ int dc_mkdir( const char *path, mode_t mode)
 
  	node = new_vsp_node( path );
 	if( node == NULL ) {
-		free(url->file);
-		free(url->host);
-		if( url->prefix != NULL ) free(url->prefix);
-		free(url);
+		free_url(url);
 		return 1;
 	}
 
 	node->url = url;
-	if (url->type == URL_PNFS) {
-		node->pnfsId = (char *)strdup(url->file);
-	}else{
-		node->pnfsId = (char *)strdup(path);
-	}
+	node->pnfsId = get_url_string(url);
 	node->asciiCommand = DCAP_CMD_MKDIR;
 
 	/* get the mask */
