@@ -119,7 +119,7 @@ int file2file( const char *source, const char *destination, int overwrite, size_
 	int isStdout = 0;
 	struct stat sbuf;
 	char extracommand[128];
-	char *real_destination;
+	char *real_destination = NULL;
 	int isDir = 0;
 
 #ifdef WIN32
@@ -231,7 +231,7 @@ int file2file( const char *source, const char *destination, int overwrite, size_
 
 	if (rc != -1 )  {
 		copy_time = endtime-starttime ;
-		fprintf(stderr,"%s => %s: %lld bytes in %lu seconds",source, destination, (off_t)size, copy_time);
+		fprintf(stderr,"%s => %s: %ld bytes in %lu seconds",source, destination, size, copy_time);
 		if ( copy_time > 0) {
 			fprintf(stderr," (%.2f KB/sec)\n",(double)size/(double)(1024*copy_time) );
 		}else{
@@ -318,11 +318,7 @@ int copyfile(int src, int dest, size_t bufsize, off_t *size)
 
 void usage()
 {
-	fprintf(stderr,"DiskCache Copy Program. LibDCAP version: %d.%d.%d-%s\n",
-		dc_getProtocol(),
-		dc_getMajor(),
-		dc_getMinor(),
-		dc_getPatch());
+	fprintf(stderr,"DiskCache Copy Program. LibDCAP version: %s\n", getDcapVersion());
 	fprintf(stderr,"Usage:  dccp [-d <debugLevel>]  [-h <replyhostname>] [-i]\n");
 	fprintf(stderr,"    [-B <bufferSize>] [-X <extraOption>]\n");
 	fprintf(stderr,"    [-u] [-p <first port>[:last port]]\n");
